@@ -3,16 +3,15 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menu.c,v 1.22 2003/11/30 21:52:11 dom Exp $
- *   $Date: 2003/11/30 21:52:11 $
+ *   $Id: menu.c,v 1.1.1.1 2003/12/04 00:10:12 dom Exp $
+ *   $Date: 2003/12/04 00:10:12 $
  *
  *
  *   Constructs a menu and all such things
  *
  */
 
-#include "mediamvp.h"
-#include "keys.h"
+#include "menuapp.h"
 
 
 /* Number of rows we can display on the menu */
@@ -40,8 +39,8 @@ typedef struct {
 struct _menu {
     dongle_t     *dongle;
     render_t     *render;
-    void         *app;
-    gui_t        *gui;
+    app_t        *app;
+    void         *param;
     int           numoptions;
     option_t     *options;
     char         *title;
@@ -49,11 +48,11 @@ struct _menu {
     int           current_selection;
     int           maxrows;                /*!< Number of lines that can be displayed on screen */
     int           flags;
-    void         (*app_clearup)(void *ptr);
+    void         (*param_clearup)(void *ptr);
     menu_t        *parent;
     menu_t        *child;
     char          *colours[4];   
-    int          (*colour_func)(menu_t *menu,void *app, int key, int sel);
+    int          (*colour_func)(menu_t *menu,void *param, int key, int sel);
 };
 
 #define MENU_ROWS(menu)  ((menu)->maxrows -  3)
@@ -62,21 +61,21 @@ static int        menu_keys(void *ptr, int code);
 
 
 
-menu_t *new_menu(dongle_t *dongle,render_t *render, menu_t *parent, void *app, int flags)
+menu_t *new_menu(dongle_t *dongle,render_t *render, app_t *app,menu_t *parent, void *param, int flags)
 {
     menu_t       *menu = malloc(sizeof(*menu));
 
     menu->dongle = dongle;
     menu->render = render;
     menu->app    = app;
-    menu->gui    = dongle->gui;
+    menu->param  = param;
     menu->title  = NULL;
     menu->top_offset = 0;
     menu->numoptions = 0;
     menu->options = NULL;
     menu->current_selection = 0;
     menu->flags   = flags;
-    menu->app_clearup = NULL;
+    menu->param_clearup = NULL;
     menu->maxrows = render_get_maxrows(render);
     menu->colours[0] = menu->colours[1] = menu->colours[2] = menu->colours[3] = NULL;
 
@@ -123,8 +122,8 @@ void delete_menu(menu_t *menu)
         free(menu->options);
     }
 
-    if ( menu->app_clearup ) {
-        (menu->app_clearup)(menu->app);
+    if ( menu->param_clearup ) {
+        (menu->param_clearup)(menu->param);
     }
 
     for ( i = 0; i < 3; i++ ) {
@@ -147,7 +146,7 @@ void menu_set_title(menu_t *menu, char *text)
 }
 
 
-void menu_add_option(menu_t *menu, char *name, int (callback_func)(menu_t *menu,void *app, int sel),
+void menu_add_option(menu_t *menu, char *name, int (callback_func)(menu_t *menu,void *param, int sel),
                      int type, int num_options, char **options, void *value_ptr)
 {
     int     i = menu->numoptions++;
@@ -162,7 +161,7 @@ void menu_add_option(menu_t *menu, char *name, int (callback_func)(menu_t *menu,
     menu->options[i].value_ptr = value_ptr;
 }
 
-void menu_add(menu_t *menu, char *name, int (*callback_func)(menu_t *menu,void *app, int sel))
+void menu_add(menu_t *menu, char *name, int (*callback_func)(menu_t *menu,void *param, int sel))
 {
     int     i = menu->numoptions++;
 
@@ -193,7 +192,6 @@ void menu_display(menu_t *menu)
         menu = menu->child;
     }
 
-    printf("Displaying menu\n");
     render_set_bgcol(render,BLACK);
     render_clear(render);
 
@@ -268,7 +266,7 @@ void menu_display(menu_t *menu)
         }
     }
         
-    gui_register_keys(menu->gui,REGISTER_MENU,menu_keys,menu);
+    app_register_keys(menu->app,REGISTER_MENU,menu_keys,menu);
 }
 
 
@@ -276,8 +274,8 @@ static int menu_keys(void *ptr, int code)
 {
     menu_t    *menu = ptr;
     int        pos;
-    int      (*func)(menu_t *,void *app, int sel);
-    int      (*cfunc)(menu_t *,void *app, int key,int sel);
+    int      (*func)(menu_t *,void *param, int sel);
+    int      (*cfunc)(menu_t *,void *param, int key,int sel);
     option_t  *option;
     unsigned int       *num;
     int      streamtype = 0;
@@ -305,7 +303,7 @@ static int menu_keys(void *ptr, int code)
             }
 
             func = menu->options[menu->current_selection].callback_func;
-            if ( func && func(menu,menu->app,menu->current_selection) == 0 ) {
+            if ( func && func(menu,menu->param,menu->current_selection) == 0 ) {
                 menu_t  *parent;                
                 parent = menu->parent;
                 delete_menu(menu);
@@ -325,7 +323,7 @@ static int menu_keys(void *ptr, int code)
                 }
             }
             func = menu->options[menu->current_selection].callback_func;
-            if ( func && func(menu,menu->app,menu->current_selection) == 0 ) {
+            if ( func && func(menu,menu->param,menu->current_selection) == 0 ) {
                 menu_t  *parent;                
                 parent = menu->parent;
                 delete_menu(menu);
@@ -371,7 +369,7 @@ static int menu_keys(void *ptr, int code)
             if ( streamtype == ( MEDIA_MPEG | MEDIA_SOCKET ) ) {
                 menu_t  *parent;
                 func = menu->options[menu->current_selection].callback_func;
-                if ( func && func(menu,menu->app,menu->current_selection) == 0 ) {
+                if ( func && func(menu,menu->param,menu->current_selection) == 0 ) {
                     parent = menu->parent;
                     delete_menu(menu);
                     parent->child = NULL;        
@@ -389,7 +387,7 @@ static int menu_keys(void *ptr, int code)
             num = option->value_ptr;           
             *num = ( *num + 1 ) % option->num_options;
             func = menu->options[menu->current_selection].callback_func;
-            if ( func && func(menu,menu->app,-1) == 0 ) {
+            if ( func && func(menu,menu->param,-1) == 0 ) {
                 delete_menu(menu);
                 parent->child = NULL;        
             }    
@@ -408,7 +406,7 @@ static int menu_keys(void *ptr, int code)
                 *num = ( *num - 1 ) % option->num_options;
             }
             func = menu->options[menu->current_selection].callback_func;
-            if ( func && func(menu,menu->app,-1) == 0 ) {
+            if ( func && func(menu,menu->param,-1) == 0 ) {
                 delete_menu(menu);
                 parent->child = NULL;        
             }      
@@ -456,7 +454,7 @@ static int menu_keys(void *ptr, int code)
         if ( menu->options != NULL ) {
             menu_t  *parent;
             func = menu->options[menu->current_selection].callback_func;
-            if ( func && func(menu,menu->app,menu->current_selection) == 0 ) {
+            if ( func && func(menu,menu->param,menu->current_selection) == 0 ) {
                 parent = menu->parent;
                 delete_menu(menu);
                 parent->child = NULL;        
@@ -469,7 +467,7 @@ static int menu_keys(void *ptr, int code)
             pos = code - k1;
             if ( pos < menu->numoptions && menu->options ) {
                 func = menu->options[pos].callback_func;
-                if ( func && func(menu,menu->app,pos) == 0 ) {
+                if ( func && func(menu,menu->param,pos) == 0 ) {
                     delete_menu(menu);
                 }
             }
@@ -477,7 +475,7 @@ static int menu_keys(void *ptr, int code)
         break;
     case kRed ... kBlue:
         cfunc = menu->colour_func;        
-        if ( cfunc && cfunc(menu,menu->app,code,menu->current_selection) == 0 ) {
+        if ( cfunc && cfunc(menu,menu->param,code,menu->current_selection) == 0 ) {
 	    menu_t *parent;
             parent = menu->parent;
             delete_menu(menu);
@@ -492,16 +490,16 @@ static int menu_keys(void *ptr, int code)
 }
 
 
-/** \brief Set the clearup pointer for the app datatype 
+/** \brief Set the clearup pointer for the param datatype 
  * 
  *  \param menu Menu handle
  *  \param clearup Function to call to clearup
  *
  *  Used for those situations when we recurse down through directory structures
  */
-void menu_set_app_clearup(menu_t *menu, void (*clearup)(void *ptr))
+void menu_set_param_clearup(menu_t *menu, void (*clearup)(void *ptr))
 {
-    menu->app_clearup = clearup;
+    menu->param_clearup = clearup;
 }
 
 
@@ -516,11 +514,11 @@ void menu_set_app_clearup(menu_t *menu, void (*clearup)(void *ptr))
  *                 pressed
  */
 void menu_set_colour_actions(menu_t *menu,
-			     char   *red,
-			     char   *green,
-			     char   *yellow,
-			     char   *blue,
-			     int   (*func)(menu_t *menu,void *app, int key, int sel))
+                             char   *red,
+                             char   *green,
+                             char   *yellow,
+                             char   *blue,
+                             int   (*func)(menu_t *menu,void *param, int key, int sel))
 {
     int     i;
 
